# addlicence

Python package for adding license for source files.

```sh
$ pip install addlicense
```

Usage:

```sh
python -m addlicense -extension py -folder src -author Odd Gunnar Aspaas -year 2021
```

Currently only support Apache v2.0.
